@@ -21,8 +21,8 @@ fi
 archstr=`uname -m`
 if [[ "$archstr" == 'ppc64le' ]]; then
     TEST_NPROCS=1
-#elif [[ "$archstr" == 'aarch64' ]]; then
-#    TEST_NPROCS=4
+elif [[ "$archstr" == 'aarch64' ]]; then
+    TEST_NPROCS=4
 else
     TEST_NPROCS=${CPU_COUNT}
 fi
